@@ -171,6 +171,18 @@ class BaseErrorCode(Enum):
         code, msg = self.__get_code_message()
         return ServiceException(code=code, msg=msg.format(**kwargs))
 
+    def build_value_error(self):
+        code, msg = self.__get_code_message()
+        return ValueError(msg)
+
+    def build_params_value_error(self, *args):
+        code, msg = self.__get_code_message()
+        return ValueError(msg.format(*args))
+
+    def build_key_params_value_error(self, **kwargs):
+        code, msg = self.__get_code_message()
+        return ValueError(msg.format(**kwargs))
+
 
 def init_app(app: Flask, lang_list: List[str], header_language_name: str = 'language',
              header_language_function=None, i18n_language_default: str = None, i18n_language_mapping: dict = None):
